@@ -401,9 +401,9 @@ otherprog:
 		}
 
 		if (fflush(mfp) == EOF
-#ifdef	NFSFSYNC
-		    || fsync(mfp) < 0
-#endif	/* NFSFSYNC */
+/* #ifdef NFSFSYNC */  /* This is propably ALWAYS a good idea.. */
+		    || fsync(fileno(mfp)) < 0
+/* #endif */	/* NFSFSYNC */
 		    || ferror(mfp)) {
 			mail_abort(mfp);
 			mfp = deadletter(uid);
@@ -432,7 +432,7 @@ otherprog:
 						/* [mea@utu.fi] I vote for
 						   removing this line if next
 						   is a RFC-header */
-						buf2 = (char*)malloc(2+strlen(buf));
+						buf2 = emalloc(2+strlen(buf));
 						if (!buf2) { errflg=1; break; }
 						strcpy(buf2,buf);
 						continue;
