@@ -921,7 +921,7 @@ functype(fname, shcmdpp, sfdpp)
 	struct shCmd **shcmdpp;
 	struct sslfuncdef **sfdpp;
 {
-	u_int symid;
+	spkey_t symid;
 	struct sslfuncdef *sfdp;
 	struct spblk *spl;
 
