@@ -1234,7 +1234,7 @@ run_listexpand(avl, il)
 	struct token **pt, *t;
 	struct addr *pp;
 	struct conscell *attributes, *tmp;
-	struct conscell *al, *alp;
+	struct conscell *al, *alp = NULL;
 	char *localpart, *origaddr;
 	int c, n, len, errflag, stuff, cnt;
 	char *comment, *erroraddress;
@@ -1264,7 +1264,9 @@ run_listexpand(avl, il)
 	      erroraddress = (char*)cdr(il)->string;
 	      break;
 	    case 'E':
-	      errors_to = (char*)cdr(il)->string;
+	      if (errors_to != olderrors)
+		free(errors_to);
+	      errors_to = strdup((char*)cdr(il)->string);
 	      break;
 	    default:
 	      errflag = 1;
@@ -1280,6 +1282,8 @@ run_listexpand(avl, il)
 		fprintf(stderr,
 			"Usage: %s [ -e error-address ] [ -E errors-to-address ] [ -c comment ] $attribute $localpart $origaddr < /file/path \n",
 			car(avl)->string);
+		if (errors_to != olderrors)
+		  free(errors_to);
 		errors_to = olderrors;
 		return NULL;
 	}
@@ -1317,6 +1321,8 @@ run_listexpand(avl, il)
 #ifdef DEBUG_FOPEN
 		report_fds(stderr);
 #endif
+		if (errors_to != olderrors)
+		  free(errors_to);
 		errors_to = olderrors;
 		return NULL;
 	}
@@ -1419,6 +1425,8 @@ run_listexpand(avl, il)
 	      printf("%s\n", erroraddress);
 	    fprintf(stderr, "%s: null input\n", car(avl)->string);
 	  }
+	  if (errors_to != olderrors)
+	    free(errors_to);
 	  errors_to = olderrors;
 	  return NULL;
 	}
@@ -1483,6 +1491,8 @@ run_listexpand(avl, il)
 		      s_grind(s_value, stderr);
 		      s_free_tree(s_value);
 		      s_value = NULL;
+		      if (errors_to != olderrors)
+			free(errors_to);
 		      errors_to = olderrors;
 		      return NULL;
 		    }
@@ -1535,10 +1545,10 @@ run_listexpand(avl, il)
 	  cddr(al) = newstring((u_char*)strsave(localpart));
 	  al = ncons(al);
 	  al = ncons(al);
-	  errors_to = olderrors;
-	  return al;
 	}
 
+	if (errors_to != olderrors)
+	  free(errors_to);
 	errors_to = olderrors;
 	return al;
 
@@ -1578,7 +1588,9 @@ run_listaddrs(argc, argv)
 			erroraddress = optarg;
 			break;
 		case 'E':
-			errors_to = (void*)strsave(optarg);
+			if (errors_to != old_errorsto)
+			  free(errors_to);
+			errors_to = (void*)strdup(optarg);
 			break;
 		default:
 			++errflag;
@@ -1586,10 +1598,13 @@ run_listaddrs(argc, argv)
 		}
 	}
 	if (errflag) {
-		fprintf(stderr,
-			"Usage: %s [ -e error-address ] [ -E errors-to-address ] [ -c comment ]\n",
-			argv[0]);
-		return 1;
+	  fprintf(stderr,
+		  "Usage: %s [ -e error-address ] [ -E errors-to-address ] [ -c comment ]\n",
+		  argv[0]);
+	  if (errors_to != old_errorsto)
+	    free(errors_to);
+	  errors_to = old_errorsto;
+	  return 1;
 	}
 	e = (struct envelope *)tmalloc(sizeof (struct envelope));
 	e->e_nowtime = now;
@@ -1617,6 +1632,9 @@ run_listaddrs(argc, argv)
 #ifdef DEBUG_FOPEN
 		report_fds(stderr);
 #endif
+		if (errors_to != old_errorsto)
+		  free(errors_to);
+		errors_to = old_errorsto;
 		return 1;
 	}
 	fd2 = dup(0);	/* Copy the file handle for latter returning
@@ -1717,6 +1735,9 @@ run_listaddrs(argc, argv)
 	      printf("%s\n", erroraddress);
 	    fprintf(stderr, "%s: null input\n", argv[0]);
 	  }
+	  if (errors_to != old_errorsto)
+	    free(errors_to);
+	  errors_to = old_errorsto;
 	  return 1;
 	}
 	for (ap = hs.h_contents.a; ap != NULL; ap = ap->a_next) {
@@ -1733,6 +1754,9 @@ run_listaddrs(argc, argv)
 	 * XX: If the alias expansion was a mail group,
 	 * we didn't print anything.
 	 */
+	if (errors_to != old_errorsto)
+	  free(errors_to);
+	errors_to = old_errorsto;
 	return 0;
 }
 
@@ -2014,7 +2038,7 @@ run_recase(argc, argv)
 	char *argv[];
 {
 	char *cp;
-	int c, flag, errflg, action;
+	int c, flag, errflg, action = 0;
 
 	optind = 1;
 	errflg = 0;
