@@ -561,18 +561,18 @@ getrrtype(host, rrtype, ttlp, depth)
 		if (rrtype == T_CNAME && hp->rcode == NOERROR) {
 			if (qdcount > 0 && strchr(host, '.') == NULL) {
 				cp = (msgdata *)&answer + sizeof(HEADER);
-				if (dn_expand((msgdata *)&answer,
-					      eom,cp,hb,sizeof hb)>=0) {
+				if (dn_expand((msgdata *)&answer,eom,cp,
+					      (u_char*)hb,sizeof hb)>=0) {
 					if (hb[0] == '\0') {
 						hb[0] = '.'; hb[1] = '\0';
 					}
-					return newstring(strsave(hb));
+					return newstring((u_char*)strsave(hb));
 				}
 			}
-			return newstring(strsave(host));
+			return newstring((u_char*)strsave(host));
 		}
 		if (rrtype == T_WKS) /* absence of WKS means YES ... */
-			return newstring(strsave(host));
+			return newstring((u_char*)strsave(host));
 		return NULL;
 	}
 	cp = (msgdata *)&answer + sizeof(HEADER);
@@ -632,7 +632,7 @@ getrrtype(host, rrtype, ttlp, depth)
 
 			*ttlp = maxttl;
 			if ((n = (int)(*cp)) > 0 && n < sizeof hb)
-				return newstring(strnsave(cp+1, n));
+				return newstring((u_char*)strnsave((char*)cp+1, n));
 			break;
 
 		case T_WKS:
@@ -652,7 +652,7 @@ getrrtype(host, rrtype, ttlp, depth)
 			      (*(cp+(IPPORT_SMTP/8)) &
 			       (0x80>>IPPORT_SMTP%8))) {
 			    *ttlp = maxttl;
-			    return newstring(strsave(hb));
+			    return newstring((u_char*)strsave(hb));
 			  }
 			}
 			continue;
@@ -660,7 +660,7 @@ getrrtype(host, rrtype, ttlp, depth)
 		case T_A:
 		case T_SA:
 			if (rrtype == T_ANY) {
-			    return newstring(strsave(host));
+			    return newstring((u_char*)strsave(host));
 			}
 			memcpy((char *)&inaddr, cp, sizeof inaddr);
 			s = dottedquad(&inaddr);
@@ -694,8 +694,8 @@ getrrtype(host, rrtype, ttlp, depth)
 				   the PTR data was taken in as CNAME.. */
 				continue;
 
-			if ((n = dn_expand((msgdata *)&answer, eom, cp, nbuf,
-			    sizeof(nbuf))) < 0)
+			if ((n = dn_expand((msgdata *)&answer, eom, cp,
+					   nbuf, sizeof(nbuf))) < 0)
 				break;
 
 			if (type == T_CNAME && rrtype != T_ANY &&
@@ -703,7 +703,7 @@ getrrtype(host, rrtype, ttlp, depth)
 				/* chase it down */
 				getrrtype((char *)nbuf, rrtype, ttlp, depth+1);
 			*ttlp = maxttl;
-			return newstring(strsave(nbuf));
+			return newstring((u_char*)strsave((char*)nbuf));
 
 	/*	case T_AAAA:	IPv6 'A'-record */
 		case T_SOA:
@@ -723,7 +723,7 @@ getrrtype(host, rrtype, ttlp, depth)
 
 		case T_MX:
 			if (rrtype == T_ANY) {
-			    return newstring(strsave(host));
+			    return newstring((u_char*)strsave(host));
 			}
 		default:
 			fprintf(stderr,"search_res: getrrtype: non-processed RR type for host='%s' query=%d, result=%d\n",host,rrtype,type);
@@ -736,7 +736,7 @@ getrrtype(host, rrtype, ttlp, depth)
 	if (ok) {
 		*ttlp = maxttl;
 		s = first ? host : hb;
-		return newstring(strsave(s));
+		return newstring((u_char*)strsave(s));
 	}
 	return NULL;
 }
