@@ -185,6 +185,8 @@ makeLetter(e, octothorp)
 	struct header	*h;
 	int		n, inheader;
 	struct header	*ph, *nh;
+	int badcontinuationflag = 0;
+	int badsubmitflag = 0;
 
 	e->e_eHeaders = 0;
 	e->e_headers = 0;
@@ -238,8 +240,10 @@ makeLetter(e, octothorp)
 					t = t->t_next;
 				t->t_next = makeToken(linebuf, n-1);
 				t->t_next->t_type = Line;
-			} else if (!octothorp)
-				return PERR_BADCONTINUATION;
+			} else if (!octothorp) {
+				/* return PERR_BADCONTINUATION */ ;
+				badcontinuationflag = 1;
+			}
 		} else if (!inheader		/* envelope information */
 			   && (*(cp=linebuf-i) == ' ' || *cp == '\t'
 				|| *cp == '\n')) {
@@ -263,7 +267,11 @@ makeLetter(e, octothorp)
 					progname);
 				fwrite((char *)linebuf, sizeof (char), -i, stderr);
 				putc('\n', stderr);
-				return PERR_BADSUBMIT;
+				h->h_contents = hdr_scanparse(e, h, octothorp);
+				h->h_stamp = hdr_type(h);
+				/* return PERR_BADSUBMIT; */
+				badsubmitflag = 1;
+				break;
 			case eFrom:		/* pity to break the elegance */
 				hd = h->h_descriptor;
 				osem = hd->semantics;
@@ -304,6 +312,10 @@ makeLetter(e, octothorp)
 	e->e_headers = ph;
 	/* record the start of the message body for posterity */
 	e->e_msgOffset = offset(e->e_fp);
+
+	if (badsubmitflag || badcontinuationflag)
+	  squirrel(e, "unrecognized envelope information; entries discarded!");
+
 	return 0;
 }
 
