@@ -215,8 +215,7 @@ doagenda()
 	    ncuritem = vp;
 	  }
 
-	  /* ipcpause(1); */
-	  mux(1);
+	  mux(1); /* Fast check */
 
 	} while (didsomething);
 	for (vp = curitem ; vp != NULL ; vp = vp->nextitem)
@@ -383,7 +382,8 @@ spool(thread)
 	     */
 	    vp->cfp->mark = V_SELECT;
 if (verbose && vp->cfp->atspool != NULL)
-  printf("spool(): vp->cfp->atspool != NULL !\n");
+  printf("spool(): vp->cfp->atspool != NULL ! (-> \"%s\")\n",
+	 vp->cfp->atspool->linkpath);
 	    vp->cfp->atspool = vp;
 	  }
 	}
