@@ -130,7 +130,7 @@ vtxprint(vp)
 		       vp->orig[L_CHANNEL]->name, vp->orig[L_HOST]->name);
 	else
 		printf("%s/%s", ISS(vp->ce.channel), ISS(vp->ce.host));
-	printf(" 0x%x\n",(unsigned)ce);
+	printf(" 0x%lx\n",(unsigned long)ce);
 	printf("\tinterval %d\n", ce->interval);
 	printf("\texpiry %d\n", ce->expiry);
 	printf("\texpiryform %s\n", ISS(ce->expiryform));
