@@ -54,8 +54,10 @@ resources_query_nofiles()
 	int rc;
 
 	rc = getrlimit(RLIMIT_NOFILE,&rl);
-	if (rc == 0)
-	  return rl.rlim_cur;
+	if (rc == 0 && rl.rlim_cur > 10)
+	    return rl.rlim_cur;
+	else
+	  return getdtablesize();
 #else
 	(int) sysconf(_SC_OPEN_MAX);
 #endif
