@@ -199,31 +199,31 @@ main(argc, argv)
 			break;
 		}
 	if (errflg) {
-		fprintf(stderr,
-			"Usage: %s [-disvV -f configfile -L logfile -P postoffice -Q rendezvous]\n",
-			progname);
-		exit(128+errflg);
+	  fprintf(stderr,
+		  "Usage: %s [-disvV -f configfile -L logfile -P postoffice -Q rendezvous]\n",
+		  progname);
+	  exit(128+errflg);
 	}
 	if ((mailshare = getzenv("MAILSHARE")) == NULL)
-		mailshare = MAILSHARE;
+	  mailshare = MAILSHARE;
 	if ((mailbin = getzenv("MAILBIN")) == NULL)
-		mailbin = MAILBIN;
+	  mailbin = MAILBIN;
 	if ((cp = getzenv("LOGDIR")) != NULL)
-		qlogdir = cp;
+	  qlogdir = cp;
 	if (daemonflg && log == NULL) {
-		log = emalloc(2 + (u_int)(strlen(qlogdir) + strlen(progname)));
-		sprintf(log, "%s/%s", qlogdir, progname);
+	  log = emalloc(2 + (u_int)(strlen(qlogdir) + strlen(progname)));
+	  sprintf(log, "%s/%s", qlogdir, progname);
 	}
 	if (log != NULL) {
-		/* loginit is a signal handler, so can't pass log */
-		if (loginit(SIGHUP) < 0)	/* do setlinebuf() there */
-			die(1, "log initialization failure");
-		/* close and reopen log files */
-		SIGNAL_HANDLE(SIGHUP, (SIGNAL_TYPE(*)())loginit);
+	  /* loginit is a signal handler, so can't pass log */
+	  if (loginit(SIGHUP) < 0) /* do setlinebuf() there */
+	    die(1, "log initialization failure");
+	  /* close and reopen log files */
+	  SIGNAL_HANDLE(SIGHUP, (SIGNAL_TYPE(*)())loginit);
 	} else {
-		SIGNAL_IGNORE(SIGHUP); /* no surprises please */
-		setvbuf(stdout, (char *)NULL, _IOLBF, 0);
-		setbuf(stderr,NULL); /* [mea] No buffering on stdout.. */
+	  SIGNAL_IGNORE(SIGHUP); /* no surprises please */
+	  setvbuf(stdout, (char *)NULL, _IOLBF, 0);
+	  setbuf(stderr,NULL);	/* [mea] No buffering on stdout.. */
 	}
 #ifdef USE_SIGREAPER
 #ifdef SIGCLD
@@ -239,54 +239,54 @@ main(argc, argv)
 	SIGNAL_HANDLE(SIGUSR1, sig_readcf);
 #endif	/* SIGUSR1 */
 	if (verbose || version) {
-		prversion("scheduler");
-		if (version)
-			exit(0);
-		putc('\n', stderr);
+	  prversion("scheduler");
+	  if (version)
+	    exit(0);
+	  putc('\n', stderr);
 	}
 	offout = ftell(stdout);
 	offerr = ftell(stderr);
 	if (config == NULL) {
-		config = emalloc(3 + (u_int)(strlen(mailshare)
-					     + strlen(progname)
-					     + strlen(qcf_suffix)));
-		sprintf(config, "%s/%s.%s", mailshare, progname, qcf_suffix);
+	  config = emalloc(3 + (u_int)(strlen(mailshare)
+				       + strlen(progname)
+				       + strlen(qcf_suffix)));
+	  sprintf(config, "%s/%s.%s", mailshare, progname, qcf_suffix);
 	}
 	if ((tp = readconfig(config)) == NULL) {
-		cp = emalloc(strlen(config)+50);
-		sprintf(cp, "null control file: %s", config);
-		die(1, cp);
-		/* NOTREACHED */
+	  cp = emalloc(strlen(config)+50);
+	  sprintf(cp, "null control file: %s", config);
+	  die(1, cp);
+	  /* NOTREACHED */
 	}
 
 	if (postoffice == NULL && (postoffice = getzenv("POSTOFFICE")) == NULL)
-		postoffice = POSTOFFICE;
+	  postoffice = POSTOFFICE;
 	if (chdir(postoffice) < 0 || chdir(SCHEDULERDIR) < 0)
-		fprintf(stderr, "%s: cannot chdir to %s/%s.\n",
-			progname, postoffice, SCHEDULERDIR);
+	  fprintf(stderr, "%s: cannot chdir to %s/%s.\n",
+		  progname, postoffice, SCHEDULERDIR);
 	if (rendezvous == NULL && (rendezvous = getzenv("RENDEZVOUS")) == NULL)
-		rendezvous = qoutputfile;
+	  rendezvous = qoutputfile;
 	if (daemonflg) {
-		/* X: check if another daemon is running already */
-		if (!verbose
-		    && (offout < ftell(stdout) || offerr < ftell(stderr))) {
-			fprintf(stderr, "%ld %ld %ld %ld\n", offout, ftell(stdout),
-				offerr, ftell(stderr));
-			fprintf(stderr, "%s: daemon not started.\n", progname);
-			die(1, "too many scheduler daemons");
-			/* NOTREACHED */
-		}
-		detach();		/* leave worldy matters behind */
-		now = time(NULL);
-		printf("%s: scheduler daemon (%s)\n\tstarted at %s\n",
-		       progname, Version, (char *)rfc822date(&now));
+	  /* X: check if another daemon is running already */
+	  if (!verbose
+	      && (offout < ftell(stdout) || offerr < ftell(stderr))) {
+	    fprintf(stderr, "%ld %ld %ld %ld\n", offout, ftell(stdout),
+		    offerr, ftell(stderr));
+	    fprintf(stderr, "%s: daemon not started.\n", progname);
+	    die(1, "too many scheduler daemons");
+	    /* NOTREACHED */
+	  }
+	  detach();		/* leave worldy matters behind */
+	  now = time(NULL);
+	  printf("%s: scheduler daemon (%s)\n\tstarted at %s\n",
+		 progname, Version, (char *)rfc822date(&now));
 	}
 	/* Actually we want this to act as daemon,
 	   even when not in daemon mode.. */
 	killprevious(SIGTERM, pidfile);
 
 	for (i = 0; i < SIZE_L; ++i)
-		spt_mesh[i] = sp_init();
+	  spt_mesh[i] = sp_init();
 #ifdef  LOG_PID
 #ifdef  LOG_MAIL
 	openlog("scheduler", LOG_PID, LOG_MAIL);
@@ -295,21 +295,21 @@ main(argc, argv)
 #endif  /* LOG_MAIL */
 #endif  /* LOG_PID */
 	if (optind < argc) {
-		/* process the specified control files only */
-		for (; optind < argc; ++optind) {
-			if ((fd = eopen(argv[optind], O_RDWR, 0)) < 0)
-				continue;
-			/* the close(fd) is done in vtxprep */
-			cfp = schedule(fd, argv[optind], tp);
-			if (cfp == NULL) {
-			  if (verbose)
-			    fprintf(stderr, "Nothing scheduled for %s!\n",
-				    argv[optind]);
-			} else
-			  eunlink(argv[optind]);
-		}
-		doagenda();
-		exit(0);
+	  /* process the specified control files only */
+	  for (; optind < argc; ++optind) {
+	    if ((fd = eopen(argv[optind], O_RDWR, 0)) < 0)
+	      continue;
+	    /* the close(fd) is done in vtxprep */
+	    cfp = schedule(fd, argv[optind], tp);
+	    if (cfp == NULL) {
+	      if (verbose)
+		fprintf(stderr, "Nothing scheduled for %s!\n",
+			argv[optind]);
+	    } else
+	      eunlink(argv[optind]);
+	  }
+	  doagenda();
+	  exit(0);
 	}
 	mustexit = gotalarm = dumpq = rereadcf = 0;
 	canexit = 0;
@@ -337,54 +337,55 @@ main(argc, argv)
 	mal_leaktrace(1);
 #endif	/* MALLOC_TRACE */
 	while (!mustexit) {
-		int wrkcnt;
-		canexit = 0;
-		if (cp != NULL &&  time(NULL) > next_delaysweep) {
-		  /* Delayed jobs in queue.. */
-		  vtxprep_skip_any = 0;
-		  fprintf(stderr,"Delay-sweeping previously locked files\n");
-		  wrkcnt = syncweb(cp, 0, tp);
-		  if (!vtxprep_skip_any) {
-		    fprintf(stderr," ... all done!\n");
-		    free(cp);
-		    cp = NULL;
-		  } else
-		    fprintf(stderr," ... scheduled %d files successfully.\n",
-			    wrkcnt);
-		  time(&next_delaysweep);
-		  next_delaysweep += 5*60; /* Five minutes */
-		}
-		syncweb(".", 1, tp);
-		doagenda();
-		/*
-		 * Due to a possible race condition, gotalarm = 0 must
-		 * have been done inside doagenda() instead of here.
-		 */
-		/* mux on the stdout of children */
-		while (!gotalarm && numkids > 0) {
-			if (dumpq) {
-				qprint(-1);
-				dumpq = 0;
-			}
-			if (rereadcf) {
-				tp = rereadconfig(tp, config);
-				rereadcf = 0;
-			}
-			mux(0); /* Slow check */
-		}
-		canexit = 1; /* may be possible to move this after doagenda() */
-		/* wait for an alarm call */
-		while (!gotalarm) {
-			if (dumpq) {
-				qprint(-1);
-				dumpq = 0;
-			}
-			if (rereadcf) {
-				tp = rereadconfig(tp, config);
-				rereadcf = 0;
-			}
-			mux(0); /* Slow check */
-		}
+	  int wrkcnt;
+	  canexit = 0;
+	  if (cp != NULL &&  time(NULL) > next_delaysweep) {
+	    /* Delayed jobs in queue.. */
+	    vtxprep_skip_any = 0;
+	    fprintf(stderr,"Delay-sweeping previously locked files\n");
+	    wrkcnt = syncweb(cp, 0, tp);
+	    if (!vtxprep_skip_any) {
+	      fprintf(stderr," ... all done!\n");
+	      free(cp);
+	      cp = NULL;
+	    } else
+	      fprintf(stderr,
+		      " ... scheduled %d files successfully, %d skipped.\n",
+		      wrkcnt, vtxprep_skip_any);
+	    time(&next_delaysweep);
+	    next_delaysweep += 5*60; /* Five minutes */
+	  }
+	  syncweb(".", 1, tp);
+	  doagenda();
+	  /*
+	   * Due to a possible race condition, gotalarm = 0 must
+	   * have been done inside doagenda() instead of here.
+	   */
+	  /* mux on the stdout of children */
+	  while (!gotalarm && numkids > 0) {
+	    if (dumpq) {
+	      qprint(-1);
+	      dumpq = 0;
+	    }
+	    if (rereadcf) {
+	      tp = rereadconfig(tp, config);
+	      rereadcf = 0;
+	    }
+	    mux(0);		/* Slow check */
+	  }
+	  canexit = 1;		/* may be possible to move this after doagenda() */
+	  /* wait for an alarm call */
+	  while (!gotalarm) {
+	    if (dumpq) {
+	      qprint(-1);
+	      dumpq = 0;
+	    }
+	    if (rereadcf) {
+	      tp = rereadconfig(tp, config);
+	      rereadcf = 0;
+	    }
+	    mux(0);		/* Slow check */
+	  }
 	}
 #ifdef	MALLOC_TRACE
 	mal_dumpleaktrace(stderr);
@@ -466,7 +467,7 @@ syncweb(dir, nukefile, cehead)
 	  if (mustexit)
 	    break;
 
-	  mux(1); /* Fast check */
+	  /* mux(1); /* Fast check */
 
 	  if (isascii(dp->d_name[0]) && isdigit(dp->d_name[0])) {
 	    if (strcmp(dir, ".") == 0)
@@ -482,12 +483,12 @@ syncweb(dir, nukefile, cehead)
 		   directory, we may have this file in processing state...  */
 		struct spblk *spl;
 		fstat(fd,&stbuf);
-		spl = sp_lookup((u_int)stbuf.st_ino, spt_mesh[L_CTLFILE]);
+		spl = sp_lookup((long)stbuf.st_ino, spt_mesh[L_CTLFILE]);
 		if (spl != NULL) {
 		  /* Already in processing, don't touch.. */
 		  /*printf("File: %s active (not previously locked)\n",file);*/
 		  close(fd);
-		  vtxprep_skip_any |= 1;
+		  ++vtxprep_skip_any;
 		  continue;
 		}
 		/* Ok, perhaps it is not in active processing, sync it in.. */
@@ -554,7 +555,7 @@ schedule(fd, file, cehead)
 	    if (verbose)
 	      printf("completed, unlink %s\n",file);
 	  }
-	  vtxprep_skip_any |= vtxprep_skip;
+	  vtxprep_skip_any += vtxprep_skip;
 	  return NULL;
 	}
 	if (cfp->head == NULL) {
@@ -616,14 +617,14 @@ slurp(fd)
 	  close(fd);
 	  return NULL;	/* XX: give error */
 	}
-	contents = emalloc((u_int) stbuf.st_size+1);
+	contents = emalloc(stbuf.st_size+1);
 	if (eread(fd, contents, stbuf.st_size) != stbuf.st_size) { /* slurp */
 	  close(fd);
 	  return NULL;
 	}
 	contents[stbuf.st_size] = 0;
 
-	cfp = (struct ctlfile *)emalloc((u_int) (sizeof(struct ctlfile)));
+	cfp = (struct ctlfile *)emalloc(sizeof(struct ctlfile));
 	memset((void*)cfp, 0, sizeof(struct ctlfile));
 
 	cfp->fd = fd;
@@ -717,6 +718,11 @@ lockverify(cfp,cp)		/* Return 1 when lock process does not exist */
 {
 	char	lockbuf[1+_CFTAG_RCPTPIDSIZE];
 	int	lockpid;
+	int	sig = 0;
+
+#ifdef SIGCONT	/* OSF/1 acts differently if we use SIGNAL 0 :-( */
+	sig = SIGCONT;
+#endif
 
 	++cp;
 	if (!(*cp == ' ' ||
@@ -724,7 +730,7 @@ lockverify(cfp,cp)		/* Return 1 when lock process does not exist */
 	memcpy(lockbuf,cp,_CFTAG_RCPTPIDSIZE);
 	lockbuf[sizeof(lockbuf)-1] = 0;
 	if (sscanf(lockbuf,"%d",&lockpid) != 1) return 1; /* Bad value ? */
-	if (kill(lockpid,0) != 0) return 1; /* PID does not exist, or
+	if (kill(lockpid,sig) != 0) return 1; /* PID does not exist, or
 					       other error.. */
 	fprintf(stderr,"lockverify: Lock with PID=%d is active on %s:%s\n",
 		lockpid, cfp->logident, cp+_CFTAG_RCPTPIDSIZE);
@@ -749,7 +755,7 @@ vtxprep(cfp)
 	if (cfp == NULL)
 	  return NULL;
 
-	sp_install((u_int)cfp->id, (u_char *)cfp, 0, spt_mesh[L_CTLFILE]);
+	sp_install(cfp->id, (u_char *)cfp, 0, spt_mesh[L_CTLFILE]);
 	channel = host = NULL;
 	/* copy offsets into local array */
 	offspc = 16;
@@ -779,7 +785,7 @@ vtxprep(cfp)
 	       * won't errorneously delete it.
 	       */
 	      close(cfp->fd);	/* Was opened on  schedule() */
-	      spl = sp_lookup((u_int)cfp->id, spt_mesh[L_CTLFILE]);
+	      spl = sp_lookup(cfp->id, spt_mesh[L_CTLFILE]);
 	      if (spl != NULL)
 		sp_delete(spl, spt_mesh[L_CTLFILE]);
 	      if (cfp->vfp != NULL) {
@@ -789,7 +795,7 @@ vtxprep(cfp)
 	      }
 	      free(cfp->contents);
 	      free((char *)cfp);
-	      vtxprep_skip = 1;
+	      ++vtxprep_skip;
 	      return NULL;
 	    }
 	    *cp = _CFTAG_NORMAL; /* unlock it */
@@ -934,7 +940,7 @@ vtxprep(cfp)
 	  sprintf(mfpath, "../%s/%s", QUEUEDIR, cfp->mid);
 	if (cfp->mid == NULL || cfp->logident == NULL
 	    || estat(mfpath, &stbuf) < 0) {
-	  spl = sp_lookup((u_int)cfp->id, spt_mesh[L_CTLFILE]);
+	  spl = sp_lookup(cfp->id, spt_mesh[L_CTLFILE]);
 	  if (spl != NULL)
 	    sp_delete(spl, spt_mesh[L_CTLFILE]);
 	  if (cfp->vfp != NULL) {
@@ -1344,7 +1350,7 @@ file_to_ctl(s)
 	else
 	  ++file;
 
-	spl = sp_lookup((u_int)atoi(file), spt_mesh[L_CTLFILE]);
+	spl = sp_lookup((u_long)atol(file), spt_mesh[L_CTLFILE]);
 	if (spl == NULL)
 	  return NULL;
 	return (struct ctlfile *)spl->data;
