@@ -19,11 +19,11 @@ struct config_entry {
 	struct config_entry *next;
 	char	*channel;	/* channel part of pattern */
 	char	*host;		/* host part of pattern */
-	u_int	interval;	/* how often to start up these things */
-	u_int	expiry;		/* bounce the message after this long in q's */
+	time_t	interval;	/* how often to start up these things */
+	time_t	expiry;		/* bounce the message after this long in q's */
 	char	*expiryform;	/* use this form as the error message */
-	int	uid;		/* what uid to run the transport agent under */
-	int	gid;		/* what gid to run the transport agent under */
+	uid_t	uid;		/* what uid to run the transport agent under */
+	gid_t	gid;		/* what gid to run the transport agent under */
 	char	*command;	/* the command to run */
 	short	bychannel;	/* indicates $channel occurs in command */
 	short	byhost;		/* indicates $host occurs in command */
@@ -59,7 +59,7 @@ extern struct sptree *spt_mesh[SIZE_L];
 struct ctlfile {
 	int	fd;		/* a file descriptor pointing at the file */
 	FILE	*vfp;		/* a FILE * for verbose logging for mail -v */
-	int	uid;		/* the owner of the control file (== msg file)*/
+	uid_t	uid;		/* the owner of the control file (== msg file)*/
 	time_t	ctime;		/* when this file was created (more or less) */
 	int	haderror;	/* some errors/diagnostics need processing */
 	struct vertex	*head;		/* head of the list of groups */
@@ -70,7 +70,7 @@ struct ctlfile {
 	char	*erroraddr;	/* error address(es) */
 	char	*deliveryform;	/* [mea] Name of delivery error form */
 	char	*envid;		/* DSN envid */
-	ino_t	id;		/* identification # (inode# of control file) */
+	u_long	id;		/* identification # (inode# of control file) */
 	char	*mid;		/* msg identification (name of message file) */
 	int	mark;		/* flag used by selector() to pass filenames */
 	int	msgbodyoffset;	/* size of original headers to skip on errrpt*/
@@ -88,7 +88,7 @@ struct web {
 };
 
 struct procinfo {
-	int	pid;
+	pid_t	pid;
 	int	reaped;
 	struct web *ch;
 	struct web *ho;
