@@ -68,9 +68,6 @@ tscan(spl)
 	struct spblk *spl;
 {
 	struct ctlfile *cfp = (struct ctlfile *)spl->data;
-#if 0
-	char *dir, path[MAXPATHLEN], buf[MAXPATHLEN];
-#endif
 
 	/* assert cfp != NULL */
 
@@ -86,38 +83,44 @@ tscan(spl)
 	  t_nmax = 0;
 	  /* Clear the markings.. */
 	  cfp->mark    = V_NONE;
-	  cfp->atspool = NULL;
+	  /* cfp->atspool = NULL; */
 	  return -1;
 	}
-#if 0
-	/*
-	 * XX: Note that any old filename will do for the control file,
-	 * since all names are links to the same file anyway.
-	 * However, we need to get the filename right, based on
-	 * our favorite filename generation technique.
-	 *
-	 * XX: Wrong, not just ANY, it MUST match the thing each
-	 *     transporter expects!  Thus when all hosts become
-	 *     processed, the links can be released.
-	 *
-	 * Solution: We use  cfp->atspool/*vertex*/->linkpath  for it!
-	 */
+#if 1
+	{
+	  char *dir, path[MAXPATHLEN], buf[MAXPATHLEN];
 
-	if (subsubdirs)	/* channel/host */
-	  dir = vtx_to_dir(cfp->atspool, buf);
-	else		/* channel */
-	  dir = cfp->atspool->orig[L_CHANNEL]->name;
-	sprintf(path, "%s/%lu", dir, cfp->id);
+	  /*
+	   * XX: Note that any old filename will do for the control file,
+	   * since all names are links to the same file anyway.
+	   * However, we need to get the filename right, based on
+	   * our favorite filename generation technique.
+	   *
+	   * XX: Wrong, not just ANY, it MUST match the thing each
+	   *     transporter expects!  Thus when all hosts become
+	   *     processed, the links can be released.
+	   *
+	   * Solution: We use  cfp->atspool ((vertex)) ->linkpath  for it!
+	   */
 
-	if (verbose)
-	  printf("  tscan() path=\"%s\"\n",path);
-#endif
+	  if (subsubdirs)	/* channel/host */
+	    dir = vtx_to_dir(cfp->atspool, buf);
+	  else		/* channel */
+	    dir = cfp->atspool->orig[L_CHANNEL]->name;
+	  sprintf(path, "%s/%lu", dir, cfp->id);
+
+	  if (verbose)
+	    printf("  tscan() path=\"%s\"\n",path);
+	  t_files[t_n++] = path;
+	}
+#else
 	if (verbose)
 	  printf("  tscan() path=\"%s\"\n",cfp->atspool->linkpath);
 
 	t_files[t_n++] = cfp->atspool->linkpath;
+#endif
 	cfp->mark    = V_NONE;
-	cfp->atspool = NULL;
+	/* cfp->atspool = NULL; */
 	return 0;
 }
 
