@@ -62,14 +62,15 @@ update(diagnostic)
 {
 	register char	*cp;
 	char	*type, *message, *notary;
-	int	inum, offset;
+	int	offset;
+	long	inum;
 	struct diagcodes *dcp;
 
 	if (*diagnostic == '#' /* DEBUG comment.. */) {
 	  fprintf(stderr, "DBGdiag: %s\n", diagnostic);
 	  return;
 	}
-	inum = atoi(diagnostic);
+	inum = atol(diagnostic);
 	if ((cp = strchr(diagnostic, '/')) == NULL) {
 	  fprintf(stderr, "Misformed diagnostic: %s\n", diagnostic);
 	  return;
@@ -159,7 +160,7 @@ if (verbose)
 		  "scheduler done processing %s\n", cfp->mid);
 	  fclose(cfp->vfp);
 	}
-	spl = sp_lookup((u_int)cfp->id, spt_mesh[L_CTLFILE]);
+	spl = sp_lookup(cfp->id, spt_mesh[L_CTLFILE]);
 	if (spl != NULL)
 	  sp_delete(spl, spt_mesh[L_CTLFILE]);
 	if (cfp->contents != NULL)
@@ -187,6 +188,7 @@ unvertex(vp)
 		  vp->orig[L_HOST]->name,
 		  vp->cfp->id);
 	  eunlink(path);
+
 if (verbose)
   printf("%s: unlink %s\n", vp->cfp->logident, path);
 
@@ -286,7 +288,8 @@ if (verbose)
 
 struct vertex *
 findvertex(inum, offset, idx)
-	int	inum, *idx;
+	long	inum;
+	int	*idx;
 	long	offset;
 {
 	struct spblk *spl;
@@ -295,7 +298,7 @@ findvertex(inum, offset, idx)
 	int	i;
 
 	/* It is NOT POSSIBLE to cache cfp, based on the inum */
-	spl = sp_lookup((u_int)inum, spt_mesh[L_CTLFILE]);
+	spl = sp_lookup((u_long)inum, spt_mesh[L_CTLFILE]);
 	if (spl == NULL || (cfp = (struct ctlfile *)spl->data) == NULL) {
 	  fprintf(stderr, "%s: cannot find control file for %d!\n",
 		  progname, inum);
@@ -542,7 +545,7 @@ expire(vp, index)
 /*ARGSUSED*/
 int
 u_ok(inum, offset, notary, message)
-	int	inum;
+	long	inum;
 	long	offset;
 	char	*notary;
 	char	*message;
@@ -574,7 +577,7 @@ u_ok(inum, offset, notary, message)
 
 int
 u_deferred(inum, offset, notary, message)
-	int	inum;
+	long	inum;
 	long	offset;
 	char	*notary;
 	char	*message;
@@ -619,7 +622,7 @@ u_deferred(inum, offset, notary, message)
 
 int
 u_error(inum, offset, notary, message)
-	int	inum;
+	long	inum;
 	long	offset;
 	char	*notary;
 	char	*message;
@@ -660,7 +663,7 @@ u_error(inum, offset, notary, message)
 
 int
 u_retryat(inum, offset, notary, message)
-	int	inum;
+	long	inum;
 	long	offset;
 	char	*notary;
 	char	*message;
