@@ -105,7 +105,6 @@ char *cmdline, *eocmdline;
 int pid;
 
 #ifndef MALLOC_TRACE
-extern unsigned int symbol();
 extern univptr_t emalloc();
 #else
 #define	MEM_MALLOC 1000
@@ -357,7 +356,8 @@ hold(s, errmsgp)
 	struct holds_info *hip;
 	static struct sptree *spt_hash = NULL;
 	struct spblk *spl;
-	int v, symid;
+	int v;
+	spkey_t symid;
 
 	colon = NULL;
 	for (cp = s; *cp != '\0'; ++cp) {
