@@ -142,9 +142,6 @@ ctlclose(dp)
 }
 
 
-/* as in: SKIPWHILE(isascii,cp) */
-#define	SKIPWHILE(X,Y)	while (*Y != '\0' && isascii(*Y) && X(*Y)) { ++Y; }
-
 static struct address *
 ctladdr(cp)
 	char *cp;
@@ -155,31 +152,36 @@ ctladdr(cp)
 	if (ap == NULL)
 		return NULL;
 	ap->link = NULL;
-	SKIPWHILE(isspace,cp);
+	/* While space: */
+	while (*cp != 0 && (*cp == ' ' || *cp == '\t')) ++cp;
 	ap->channel = cp;
-	SKIPWHILE(!isspace,cp);
+	/* While not space: */
+	while (*cp != 0 && (*cp != ' ' && *cp != '\t')) ++cp;
 	*cp++ = '\0';
-	SKIPWHILE(isspace,cp);
+	/* While space: */
+	while (*cp != 0 && (*cp == ' ' || *cp == '\t')) ++cp;
 	ap->host = cp;
 	ap->routermxes = NULL;
 	if (*cp == '(')
 	  cp = routermxes(cp,ap);  /* It is a bit complex.. */
 	else {
-	  SKIPWHILE(!isspace,cp);
+	  /* While not space: */
+	  while (*cp != 0 && (*cp != ' ' && *cp != '\t')) ++cp;
 	  *cp++ = '\0';
 	}
-	SKIPWHILE(isspace,cp);
+	/* While space: */
+	while (*cp != 0 && (*cp == ' ' || *cp == '\t')) ++cp;
 	ap->user = cp;
 	/* the user value is allowed to have embedded whitespace */
 	while (*cp != '\0')
 	  ++cp;
 	--cp;
-	while (isascii(*cp) && isdigit(*cp))
+	while (*cp >= '0' && *cp <= '9')
 	  --cp;
-	if (isascii(*cp) && *cp == '-')
+	if (*cp == '-')
 	  --cp;
 	ap->misc = cp+1;
-	while (isascii(*cp) && isspace(*cp))
+	while (*cp == ' ' || *cp == '\t')
 	  --cp;
 	*++cp = '\0';
 
@@ -284,8 +286,10 @@ ctlopen(file, channel, host, exitflagp, selectaddr, matchrouter)
 	    ap->link  = d.senders;
 	    /* Test if this is "error"-channel..
 	       If it is,  ap->user  points to NUL string. */
-	    if (strcmp(ap->channel,"error")==0)
-	      ap->user = "";
+	    /* mea: altered the scheme, we must detect the "error" channel
+	       otherwise */
+	    /* if (strcmp(ap->channel,"error")==0)
+	       ap->user = ""; */
 	    d.senders = ap;
 	    break;
 	  case _CF_RECIPIENT:
