@@ -241,7 +241,7 @@ extern void setrootuid();
 extern void process __((struct ctldesc *dp));
 extern void deliver __((struct ctldesc *dp, struct rcpt *rp, char *timestring));
 extern void program __((struct ctldesc *dp, struct rcpt *rp, char *timestring));
-extern FILE *putmail __((struct ctldesc *dp, struct rcpt *rp, int fdmail, char *timestring, char *file));
+extern FILE *putmail __((struct ctldesc *dp, struct rcpt *rp, int fdmail, char *fdopmode, char *timestring, char *file));
 extern int appendlet __((struct ctldesc *dp, struct rcpt *rp, FILE *fp, char *file, int ismime));
 extern char **environ;
 extern int writebuf __((FILE *fp, char *buf, int len, int *lastchp));
@@ -258,7 +258,6 @@ extern char *strchr(), *strrchr();
 extern int  lstat(); /* remaps to  stat() if USE_LSTAT is not defined.. */
 extern FILE *fdopen();
 #ifndef MALLOC_TRACE
-extern unsigned int symbol();
 extern univptr_t emalloc();
 #else
 struct conshell *envarlist = NULL;
@@ -935,9 +934,7 @@ deliver(dp, rp, timestring)
 	if (nbp != NULL)
 	  nbp->offset = lseek(fdmail, 0L, L_XTND);
 #endif	/* BIFF || RBIFF */
-	fp = putmail(dp, rp, fdmail, timestring, file);
-	if (mmdf_mode)
-	  fputs("\001\001\001\001\n",fp);
+	fp = putmail(dp, rp, fdmail, "a+", timestring, file);
 	
 	if (S_ISREG(st.st_mode)) {
 #ifdef	USE_NFSMBOX
@@ -977,11 +974,11 @@ deliver(dp, rp, timestring)
 }
 
 FILE *
-putmail(dp, rp, fdmail, timestring, file)
+putmail(dp, rp, fdmail, fdopmode, timestring, file)
 	struct ctldesc *dp;
 	struct rcpt *rp;
 	int fdmail;
-	char *timestring, *file;
+	char *fdopmode, *timestring, *file;
 {
 	FILE *fp;
 	int len, rc;
@@ -991,9 +988,10 @@ putmail(dp, rp, fdmail, timestring, file)
 	char *fromuser;
 	int lastch;
 
-	if ((fp = fdopen(fdmail, "a+")) == NULL) {
+	if ((fp = fdopen(fdmail, fdopmode)) == NULL) {
 	  notaryreport(NULL,NULL,NULL);
-	  DIAGNOSTIC(rp, EX_TEMPFAIL, "cannot fdopen(%d)", fdmail);
+	  DIAGNOSTIC3(rp, EX_TEMPFAIL, "cannot fdopen(%d,\"%s\")",
+		      fdmail,fdopmode);
 	  return NULL;
 	}
 
@@ -1067,8 +1065,7 @@ putmail(dp, rp, fdmail, timestring, file)
 			     if it was not set, it doesn't change.. */
 
 	/* Begin of the file, and MMDF-style ? */
-	if (eofindex == 0 && mmdf_mode == 1 /* Values 2 and 3 exist
-						on PIPEs only.. */   )
+	if (mmdf_mode == 1 /* Values 2 and 3 exist on PIPEs only.. */   )
 	  fputs("\001\001\001\001\n",fp);
 
 	fromuser = rp->addr->link->user;
@@ -1087,6 +1084,7 @@ putmail(dp, rp, fdmail, timestring, file)
 	  return NULL;
 	}
 	lastch = appendlet(dp, rp, fp, file, is_mime);
+
 	if (lastch == EOF) {
 	  /* XX: should I really do this? */
 	  fflush(fp);
@@ -1094,6 +1092,11 @@ putmail(dp, rp, fdmail, timestring, file)
 	  fclose(fp);
 	  return NULL;
 	}
+
+	/* End of the file, and MMDF-style ? */
+	if (mmdf_mode == 1 /* Values 2 and 3 exist on PIPEs only.. */   )
+	  fputs("\001\001\001\001\n",fp);
+
 	/* ---- knock-off unnecessary trailing newlines ????      ---
 	   ---- if lastch == '\n', adding ONE newline is enough ? ---
 	   if (lastch != '\n' && !ferror(fp))
@@ -1249,7 +1252,7 @@ program(dp, rp, timestring)
 	errfp = fdopen(in[0], "r");
 	/* write the message */
 	mmdf_mode += 2;
-	fp = putmail(dp, rp, out[1], timestring, rp->addr->user+1);
+	fp = putmail(dp, rp, out[1], "w", timestring, rp->addr->user+1);
 	mmdf_mode -= 2;
 	if (fp == NULL) {
 	  pid = wait(&status);
@@ -1689,16 +1692,18 @@ biff(hostname, username, offset)
 	char *hostname, *username;
 	long offset;
 {
-	int f, symid;
+	int f;
+	spkey_t symid;
 	struct hostent *hp;
-	static struct servent *sp = NULL;
 	struct sockaddr_in biffaddr, *bap;
 	struct spblk *spl;
 	static struct sptree *spt_hosts = NULL;
 	char *buf;
 
-	if (sp == NULL && (sp = getservbyname("biff", "udp")) == NULL)
-	  return;
+#define BIFF_PORT 512 /* A well-known UDP port.. */
+	/* Could do this with  getservbyname() - but sometimes (with NIS
+	   on loaded Suns) it takes AGES...  Hardwiring works as well.   */
+
 	symid = symbol(hostname);
 	if (spt_hosts == NULL)
 	  spt_hosts = sp_init();
@@ -1710,7 +1715,7 @@ biff(hostname, username, offset)
 	  biffaddr.sin_family = hp->h_addrtype;
 	  hp_init(hp);
 	  memcpy((char *)&biffaddr.sin_addr, *hp_getaddr(),  hp->h_length);
-	  biffaddr.sin_port = sp->s_port;
+	  biffaddr.sin_port = htons(BIFF_PORT);
 	  bap = (struct sockaddr_in *)emalloc(sizeof(struct sockaddr_in));
 	  *bap = biffaddr;
 	  sp_install(symid, (char *)bap, 0, spt_hosts);
@@ -1721,8 +1726,8 @@ biff(hostname, username, offset)
 	f = socket(AF_INET, SOCK_DGRAM, 0);
 	sendto(f, buf, strlen(buf)+1, 0,
 	       (struct sockaddr *)&biffaddr, sizeof biffaddr);
-	free(buf);
 	close(f);
+	free(buf);
 }
 #endif	/* BIFF || RBIFF */
 
@@ -1736,7 +1741,8 @@ readrwho()
 #define NMAX sizeof(outmp.out_name)
 #define LMAX sizeof(outmp.out_line)
 
-	int cc, width, f, n, i, symid;
+	int cc, width, f, n, i;
+	spkey_t symid;
 	register struct whod *w = &wd;
 	register struct whoent *we;
 	register char *tp, *s;
@@ -1806,7 +1812,7 @@ rbiff(nbp)
 {
 	struct spblk *spl;
 	struct userhost *uhp;
-	int symid;
+	spkey_t symid;
 
 	symid = symbol(nbp->user);
 	if ((spl = sp_lookup(symid, spt_users)) == NULL)
