@@ -240,8 +240,9 @@ process(dp, mp, verboselog)
 	    }
 	  }
 	} else {
-	  for (rp = dp->recipients; rp != NULL; rp = rp->next)
+	  for (rp = dp->recipients; rp != NULL; rp = rp->next) {
 	    deliver(dp, mp, rp, rp->next, verboselog);
+	  }
 	}
 }
 
@@ -271,10 +272,9 @@ deliver(dp, mp, startrp, endrp, verboselog)
 #endif	/* USE_UNIONWAIT */
 	int content_kind, conversion_prohibited, convertmode, ascii_clean = 0;
 
-#ifndef USE_MALLOC
 	if (lseek(dp->msgfd, dp->msgbodyoffset, L_SET) < 0L)
 		warning("Cannot seek to message body! (%m)", (char *)NULL);
-#endif
+
 	i = 0;
 	avsize = 5;
 	av = (char **)emalloc(sizeof av[0] * avsize);
@@ -332,8 +332,8 @@ deliver(dp, mp, startrp, endrp, verboselog)
 		  char msg[BUFSIZ];
 
 		  sprintf(msg,
-			  "Null value for $%c (%%s)!",
-			  *cp);
+			  "Null value for $%c (%%s) (msgfile: %s)!",
+			  *cp, dp->msgfile);
 		  warning(msg, mp->name);
 		} else {
 		  strcpy(s, ds);
@@ -626,7 +626,8 @@ appendlet(dp, mp, fp, verboselog, convertmode)
 	  char iobuf[BUFSIZ];
 	  FILE *mfp = fdopen(mfd,"r");
 
-	  writemimeline(mp, fp, (char *)NULL, 0, 0, NULL);
+	  fseek(mfp,dp->msgbodyoffset);
+
 	  setvbuf(mfp, iobuf, _IOFBF, sizeof(iobuf));
 
 #define MFPCLOSE i = dup(mfd); fclose(mfp); dup2(i,mfd); close(i);
@@ -636,20 +637,29 @@ appendlet(dp, mp, fp, verboselog, convertmode)
 #define MFPCLOSE
 	  char *s = dp->let_buffer + dp->msgbodyoffset;
 #endif
+	  writemimeline(mp, fp, (char *)NULL, 0, 0, NULL);
+
+	  /*
+	     if(verboselog) fprintf(verboselog,
+	     "sm: Convert mode: %d, fd=%d, fdoffset=%d, bodyoffset=%d\n",
+	     convertmode, mfd, (int)lseek(mfd,0,1),
+	     dp->msgbodyoffset);
+	   */
 
 	  /* we are assuming to be positioned properly
 	     at the start of the message body */
 	  bufferfull = 0;
 	  lastch = -1;
 	  i = 0;
+
 	  for (;;) {
 #ifndef USE_MMAP
 	    if ((i = cfgets(let_buffer, sizeof(let_buffer), mfp)) == EOF)
 	      break;
 #else
 	    char *let_buffer = s, *s2 = s;
-	    if (s >= dp->let_end) break;	/* "EOF" */
 	    i = 0;
+	    if (s >= dp->let_end) break;	/* "EOF" */
 	    while (s2 < dp->let_end && *s2 != '\n')
 	      ++s2, ++i;
 	    if ((lastch = *s2) == '\n')
@@ -873,11 +883,14 @@ writemimeline(mp, fp, buf, len, convertmode, lastchp)
 		if (c >= 'A') c -= ('A' - '9' -1);
 		qp_val <<= 4;
 		qp_val |= (c & 0x0F);
-		--qp_chrs;
-	      }
-	      if (!qp_chrs)
-		c = qp_val;
+		if (--qp_chrs)
+		  continue;	/* Not yet last.. */
+		else
+		  c = qp_val;	/* The second (=last) hex digit */
+	      } else
+		qp_chrs = 0;	/* While in this mode, NOT QP-hex-digit! */
 	    } /* Ok, decoded possible Q-P chars.  Now normal processing.. */
+
 	    if (column == 0 && c == '.' && (mp->flags & MO_HIDDENDOT)) {
 	      if (putc(c,fp)==EOF) return EOF;
 	    } else if (column == 0 && (mp->flags & MO_ESCAPEFROM) &&
@@ -1036,7 +1049,7 @@ readsmcf(file, mailer)
 	return &m;
 }
 
-/* When data is clean 7-BIT ...  */
+/* When data is clean 7-BIT, return 1.. (zero == non-clean) */
 int
 check_7bit_cleanness(dp)
 struct ctldesc *dp;
@@ -1045,7 +1058,15 @@ struct ctldesc *dp;
 	/* With MMAP()ed spool file it is sweet and simple.. */
 	register char *s = dp->let_buffer + dp->msgbodyoffset;
 	while (s < dp->let_end)
-	  if (128 & *s) return 0;
+	  if (128 & *s) {
+    /*
+       if (verboselog)
+       fprintf(verboselog,
+       "check_7bit_cleanness() non-clean byte on offset %d, str=\"%-8s\"\n",
+       s-(dp->let_buffer + dp->msgbodyoffset), s);
+     */
+	    return 0; /* Not clean ! */
+	  }
 	  else ++s;
 	return 1;
 #else
@@ -1059,7 +1080,7 @@ struct ctldesc *dp;
 	if (readalready != 0) {
 	  for (i=0; i<readalready; ++i)
 	    if (128 & (let_buffer[i]))
-	      return 1;		/* Not clean ! */
+	      return 0;		/* Not clean ! */
 	}
 
 	/* we are assumed to be positioned properly at start of message body */
@@ -1069,7 +1090,7 @@ struct ctldesc *dp;
 	  if (i < 0) {
 	    /* ERROR ?!?!? */
 	    if (bufferfull > 1) readalready = 0;
-	    return 1;
+	    return 0;
 	  }
 	  lastwasnl = (let_buffer[i-1] == '\n');
 	  readalready = i;
@@ -1078,7 +1099,7 @@ struct ctldesc *dp;
 	    if (128 & (let_buffer[i])) {
 	      lseek(mfd,mfd_pos,0);
 	      if (bufferfull > 1) readalready = 0;
-	      return 1;		/* Not clean ! */
+	      return 0;		/* Not clean ! */
 	    }
 	}
 	/* Got to EOF, and still it is clean 7-BIT! */
@@ -1086,6 +1107,6 @@ struct ctldesc *dp;
 	if (bufferfull > 1)	/* not all in memory, need to reread */
 	  readalready = 0;
 
-	return 0;
+	return 1;
 #endif
 }
