@@ -468,7 +468,8 @@ main(argc, argv)
 	  ctlclose(dp);
 	}
 	if (smtpstatus == EX_OK) {
-	  smtpstatus = smtpwrite(smtpfp, verboselog, 0, "QUIT");
+	  if (smtp_isopen)
+	    smtpstatus = smtpwrite(smtpfp, verboselog, 0, "QUIT");
 	}
 	/* Close the channel -- if it is open anymore .. */
 	if (smtp_isopen) {
@@ -624,7 +625,10 @@ deliver(dp, smtpfp, verboselog, startrp, endrp)
 	  } /* switch().. */
 	}
 
-	sprintf(SMTPbuf, "MAIL From:<%s>", startrp->addr->link->user);
+	if (strcmp(startrp->addr->link->channel,"error")==0)
+	  sprintf(SMTPbuf, "MAIL From:<>");
+	else
+	  sprintf(SMTPbuf, "MAIL From:<%s>", startrp->addr->link->user);
 	if (ehlo_capabilities & ESMTP_8BITMIME)
 	  strcat(SMTPbuf, " BODY=8BITMIME");
 	s = SMTPbuf + strlen(SMTPbuf);
@@ -1326,6 +1330,7 @@ smtpconn(host, fparr, verboselog)
 	int	mxcnt = 0;
 
 	hp = NULL;
+	memset(mxh,0,sizeof(mxh));
 #ifdef	BIND
 	h_errno = 0;
 #endif	/* BIND */
@@ -1554,8 +1559,19 @@ makeconn(hp, fdp, verboselog, fparr, mxcnt)
 	    if (fparr[0] != NULL) fclose(fparr[0]);
 	    if (fparr[1] != NULL) fclose(fparr[1]);
 
-	    fparr[0] = (FILE*) fdopen(*fdp, "r");
-	    fparr[1] = (FILE*) fdopen(*fdp, "w");
+	    if ((fparr[0] = fdopen(*fdp, "r")) == NULL) {
+	      int err;
+fdopen_fail:
+	      err = errno;
+	      if (fparr[0] != NULL) fclose(fparr[0]);
+	      if (fparr[1] != NULL) fclose(fparr[1]);
+printf("smtp: Failed to fdopen() a socket stream, errno=%d Hmm ??\n",err);
+fflush(stdout);
+abort();
+	    }
+	    if ((fparr[1] = fdopen(*fdp, "w")) == NULL)
+	      goto fdopen_fail;
+
 	    if (esmtp_on_banner > 0)
 	      esmtp_on_banner = 0;
 	    retval = smtpwrite(fparr, verboselog, 1, NULL);
